@@ -5,7 +5,7 @@ context("Login")
 
 test_that("Login procedure works", {
   with_mock_API({
-   # expect_POST(sst <- superSecuredToken())
+    expect_POST(sst <- superSecuredToken())
     expect_GET(sst <- temporaryToken("dummy"))
   })
 })
@@ -16,7 +16,7 @@ test_that("Login unauthorized message is correct", {
     status_code = mock(401L, cycle = T),
     buildMockURL = mock("test.com/login-401.json", cycle = T),
     with_mock_API({
-     # expect_error(sst <- superSecuredToken(), regexp = "401")
+      expect_error(sst <- superSecuredToken(), regexp = "401")
     })
   )
 })
